@@ -76,11 +76,9 @@
 .consolidate_dependent_artifacts <- function(n, n_adj, p = rep(.5, length(es)), es, es_metric, rxx, ryy, ux, uy, rxx_restricted, ryy_restricted, ux_observed, uy_observed){
      ux_out <- .consolidate_dependent_u(ux = ux, rxx = rxx, n = n, ux_observed = ux_observed, rxx_restricted = rxx_restricted)
      uy_out <- .consolidate_dependent_u(ux = uy, rxx = ryy, n = n, ux_observed = uy_observed, rxx_restricted = ryy_restricted)
-
-     if(es_metric == "d"){
-          es <- convert_es.q_d_to_r(d = es, p = p)
-     }
-
+     
+     if(es_metric == "d") es <- convert_es.q_d_to_r(d = es, p = p)
+     
      rxx_out <- .colsolidate_dependent_rel(rxx = rxx, ux = ux_out$ux, uy = uy_out$ux, n = n, n_adj = n_adj, rxyi = es, rxx_restricted = rxx_restricted, ux_observed = ux_out$ux_observed)
      ryy_out <- .colsolidate_dependent_rel(rxx = ryy, ux = uy_out$ux, uy = ux_out$ux, n = n, n_adj = n_adj, rxyi = es, rxx_restricted = ryy_restricted, ux_observed = uy_out$ux_observed)
 
@@ -121,7 +119,7 @@
           }
           
           if(length(moderator_names$all) > 0){
-               moderators <- as.data.frame(as_tibble(data, .name_repair = "minimal")[,moderator_names$all])
+               moderators <- as.data.frame(as_tibble(data, .name_repair = "minimal")[,moderator_names$all], stringsAsFactors = FALSE)
           }else{
                moderators <- NULL
           }
@@ -160,17 +158,17 @@
                
                if(!is.null(moderator_names$cat))
                     moderators_comp[,moderator_names$cat] <-
-                    apply(as.data.frame(moderators_comp_i[,moderator_names$cat]), 2, function(x){
+                    apply(as.data.frame(moderators_comp_i[,moderator_names$cat], stringsAsFactors = FALSE), 2, function(x){
                          paste(sort(unique(as.character(x))), collapse = " & ")
                     })
                
                if(!is.null(moderator_names$noncat))
                     moderators_comp[,moderator_names$noncat] <- 
-                    apply(as.data.frame(moderators_comp_i[,moderator_names$noncat]), 2, function(x){
+                    apply(as.data.frame(moderators_comp_i[,moderator_names$noncat], stringsAsFactors = FALSE), 2, function(x){
                          mean(x, na.rm = TRUE)
                     })
                
-               moderators_comp <- as.data.frame(moderators_comp)
+               moderators_comp <- as.data.frame(moderators_comp, stringsAsFactors = FALSE)
           }else{
                moderators_comp <- NULL
           }
@@ -392,6 +390,11 @@
           n_comp <- wt_mean(x = es_data$n[i], wt = es_data$n_adj[i])
           n_adj_comp <- wt_mean(x = es_data$n_adj[i], wt = es_data$n_adj[i])
           
+          if(abs(es_comp) > 1) 
+                  stop("The composite effect size for sample ID '", es_data$sample_id[i][1], "' is not possible.
+Please (a) supply alternative intercorrelations, (b) supply sample-specific intercorrelations, 
+(c) change the 'collapse_method' argument, or (d) manually consolidate the dependency among estimates.", call. = FALSE)
+          
           if(all(c("d", "n1", "n2", "pi", "pa") %in% colnames(es_data))){
                n1_comp <- wt_mean(x = es_data$n1[i], wt = es_data$n_adj[i])
                n2_comp <- wt_mean(x = es_data$n2[i], wt = es_data$n_adj[i])
@@ -471,7 +474,7 @@
      })
      
      if(!is.null(moderators)){
-          mod_out <- as.data.frame(data.table::rbindlist(lapply(out, function(x) x$moderators_comp)))
+          mod_out <- as.data.frame(data.table::rbindlist(lapply(out, function(x) x$moderators_comp)), stringsAsFactors = FALSE)
      }else{
           mod_out <- NULL
      }
@@ -523,10 +526,10 @@
      for(i in names(data_x_list)) if(is.null(data_x_list[[i]])) data_x_list[[i]] <- NULL
      for(i in names(data_y_list)) if(is.null(data_y_list[[i]])) data_y_list[[i]] <- NULL
 
-     es_data <- as.data.frame(es_data_list)
+     es_data <- as.data.frame(es_data_list, stringsAsFactors = FALSE)
      if(!is.null(mod_out)) es_data <- cbind(es_data, mod_out)
-     data_x <- as.data.frame(data_x_list)
-     data_y <- as.data.frame(data_y_list)
+     data_x <- as.data.frame(data_x_list, stringsAsFactors = FALSE)
+     data_y <- as.data.frame(data_y_list, stringsAsFactors = FALSE)
 
      rownames(es_data) <- 1:nrow(es_data)
 
@@ -534,13 +537,13 @@
           data_x <- NULL
      }else{
           rownames(data_x) <- 1:nrow(es_data)
-          es_data <- data.frame(es_data, data_x)
+          es_data <- data.frame(es_data, data_x, stringsAsFactors = FALSE)
      }
      if(nrow(data_y) == 0){
           data_y <- NULL
      }else{
           rownames(data_y) <- 1:nrow(es_data)
-          es_data <- data.frame(es_data, data_y)
+          es_data <- data.frame(es_data, data_y, stringsAsFactors = FALSE)
      }
 
      es_data
